import * as react from 'react';
import { CSSProperties } from 'react';
import { JSX } from '@emotion/react/jsx-runtime';

type SrcGeneratorProps = {
    src: string;
    width?: number;
    height?: number;
    quality?: number;
    format?: string;
    userId?: string;
    backendUrl?: string;
    folder?: "public" | "private";
    type?: "normal" | "avatar";
};
type PixelProps = {
    src: string;
    className?: string;
    alt?: string;
    style?: CSSProperties;
    background?: boolean;
    lazy?: boolean;
    width?: number;
    height?: number;
    quality?: number;
    userId?: string;
    backendUrl?: string;
    avif?: boolean;
    webp?: boolean;
    mimeType?: string;
    direct?: boolean;
    loader?: boolean;
    dynamicDimension?: boolean;
    folder?: "public" | "private";
    type?: "normal" | "avatar";
};

/**
 * Pixel component for displaying images with support for multiple formats and lazy loading.
 *
 * @component
 * @param {Object} props - Component props.
 * @param {string} props.src - The source URL of the image.
 * @param {string} [props.className] - The CSS class for the component.
 * @param {string} [props.alt="image"] - The alt text for the image.
 * @param {Object} [props.style] - Inline styles for the component.
 * @param {boolean} [props.background=false] - Whether the image is used as a background.
 * @param {boolean} [props.lazy=true] - Whether to lazy load the image.
 * @param {number} [props.width] - The width of the image.
 * @param {number} [props.height] - The height of the image.
 * @param {number} [props.quality] - The quality of the image.
 * @param {string} [props.userId] - The user ID of the image owner.
 * @param {boolean} [props.avif=true] - Whether to support AVIF format.
 * @param {boolean} [props.webp=true] - Whether to support WebP format.
 * @param {string} [props.mimeType="jpeg"] - The MIME type of the image.
 * @param {boolean} [props.direct=false] - Whether to directly load the image without conversion.
 * @param {boolean} [props.loader=true] - Whether to display a loading skeleton.
 * @param {boolean} [props.dynamicDimension=false] - Whether the image dimensions are dynamic.
 * @param {string} [props.backendUrl="/api/v1/pixel/serve"] - The backend URL for the image.
 * @param {string} [props.folder="public"] - The folder where the image is stored.
 * @param {string} [props.type="normal"] - The type of image (e.g., 'normal', 'avatar').
 * @returns {JSX.Element} The rendered component.
 */
declare const Pixel: react.MemoExoticComponent<({ src, className, alt, style, background, lazy, width, height, quality, userId, avif, webp, mimeType, direct, loader, dynamicDimension, backendUrl, folder, type, ...props }: PixelProps) => JSX.Element>;

export { type PixelProps, type SrcGeneratorProps, Pixel as default };
